Processor.process\_article
==========================

.. automodule:: Processor.process_article

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      article_process
      main
   
   

   
   
   

   
   
   



